@@ -1,2 +1,6 @@
 from .client import HkClient
 from .exceptions import *
+
+__all__ = [
+    'HkClient',
+]
\ No newline at end of file
